0.9.9 API documentation: matrix_factorisation.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
matrix_factorisation.hpp File Reference

GLM_GTX_matrix_factorisation More...

Go to the source code of this file.

## Functions
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL mat< C, R, T, Q > | fliplr (mat< C, R, T, Q > const &in)
| Flips the matrix columns right and left. More...
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL mat< C, R, T, Q > | flipud (mat< C, R, T, Q > const &in)
| Flips the matrix rows up and down. More...
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL void | qr_decompose (mat< C, R, T, Q > const &in, mat<(C< R?C:R), R, T, Q > &q, mat< C,(C< R?C:R), T, Q > &r)
| Performs QR factorisation of a matrix. More...
template<length_t C, length_t R, typename T , qualifier Q>
GLM_FUNC_DECL void | rq_decompose (mat< C, R, T, Q > const &in, mat<(C< R?C:R), R, T, Q > &r, mat< C,(C< R?C:R), T, Q > &q)
| Performs RQ factorisation of a matrix. More...

## Detailed Description

GLM_GTX_matrix_factorisation

See also
  Core features (dependence)

Definition in file matrix_factorisation.hpp.